# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/tenancy/v1/tenancy_service.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/tenancy/v1/tenancy_service.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2
from tars.cli.v1 import cli_pb2 as tars_dot_cli_dot_v1_dot_cli__pb2
from tars.common.v1 import types_pb2 as tars_dot_common_dot_v1_dot_types__pb2
from tars.docs.v1 import docs_pb2 as tars_dot_docs_dot_v1_dot_docs__pb2
from tars.tenancy.v1 import customer_pb2 as tars_dot_tenancy_dot_v1_dot_customer__pb2
from tars.tenancy.v1 import project_pb2 as tars_dot_tenancy_dot_v1_dot_project__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%tars/tenancy/v1/tenancy_service.proto\x12\x0ftars.tenancy.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1ftars/auth/v1/auth_options.proto\x1a\x15tars/cli/v1/cli.proto\x1a\x1atars/common/v1/types.proto\x1a\x17tars/docs/v1/docs.proto\x1a\x1etars/tenancy/v1/customer.proto\x1a\x1dtars/tenancy/v1/project.proto\"\x82\x01\n\x15\x43reateCustomerRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12!\n\x0c\x64isplay_name\x18\x02 \x01(\tR\x0b\x64isplayName\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\":\n\x12GetCustomerRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\"G\n\x14ListCustomersRequest\x12/\n\x04page\x18\x01 \x01(\x0b\x32\x1b.tars.common.v1.PageRequestR\x04page\"\x82\x01\n\x15ListCustomersResponse\x12\x37\n\tcustomers\x18\x01 \x03(\x0b\x32\x19.tars.tenancy.v1.CustomerR\tcustomers\x12\x30\n\x04page\x18\x02 \x01(\x0b\x32\x1c.tars.common.v1.PageResponseR\x04page\"\x82\x01\n\x15UpdateCustomerRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12!\n\x0c\x64isplay_name\x18\x02 \x01(\tR\x0b\x64isplayName\x12 \n\x0b\x64\x65scription\x18\x03 \x01(\tR\x0b\x64\x65scription\">\n\x16\x41rchiveCustomerRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\"\xa5\x01\n\x14\x43reateProjectRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12!\n\x0c\x64isplay_name\x18\x03 \x01(\tR\x0b\x64isplayName\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\"]\n\x11GetProjectRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"l\n\x13ListProjectsRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12/\n\x04page\x18\x02 \x01(\x0b\x32\x1b.tars.common.v1.PageRequestR\x04page\"~\n\x14ListProjectsResponse\x12\x34\n\x08projects\x18\x01 \x03(\x0b\x32\x18.tars.tenancy.v1.ProjectR\x08projects\x12\x30\n\x04page\x18\x02 \x01(\x0b\x32\x1c.tars.common.v1.PageResponseR\x04page\"\xa5\x01\n\x14UpdateProjectRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12!\n\x0c\x64isplay_name\x18\x03 \x01(\tR\x0b\x64isplayName\x12 \n\x0b\x64\x65scription\x18\x04 \x01(\tR\x0b\x64\x65scription\"a\n\x15\x41rchiveProjectRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\"\xa2\x01\n\x17\x41\x64\x64ProjectMemberRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12$\n\x0bidentity_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\nidentityId\x12\x17\n\x04role\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x04role\"\x96\x01\n\x19ListProjectMembersRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12/\n\x04page\x18\x03 \x01(\x0b\x32\x1b.tars.common.v1.PageRequestR\x04page\"\x88\x01\n\x1aListProjectMembersResponse\x12\x38\n\x07members\x18\x01 \x03(\x0b\x32\x1e.tars.tenancy.v1.ProjectMemberR\x07members\x12\x30\n\x04page\x18\x02 \x01(\x0b\x32\x1c.tars.common.v1.PageResponseR\x04page\"\xa5\x01\n\x1aUpdateProjectMemberRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12$\n\x0bidentity_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\nidentityId\x12\x17\n\x04role\x18\x04 \x01(\tB\x03\xe0\x41\x02R\x04role\"\x8c\x01\n\x1aRemoveProjectMemberRequest\x12$\n\x0b\x63ustomer_id\x18\x01 \x01(\tB\x03\xe0\x41\x02R\ncustomerId\x12\"\n\nproject_id\x18\x02 \x01(\tB\x03\xe0\x41\x02R\tprojectId\x12$\n\x0bidentity_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\nidentityId2\xca\x07\n\x0eTenancyService\x12\xb5\x01\n\x0e\x43reateCustomer\x12&.tars.tenancy.v1.CreateCustomerRequest\x1a\x19.tars.tenancy.v1.Customer\"`\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18\x13:\tcustomers:\x06\x63reate\xa2\xb5\x18\x11\x43reate a customer\xaa\xb5\x18\tCustomers\x82\xd3\xe4\x93\x02\x12\"\r/v1/customers:\x01*\x12\xb7\x01\n\x0bGetCustomer\x12#.tars.tenancy.v1.GetCustomerRequest\x1a\x19.tars.tenancy.v1.Customer\"h\x90\x02\x01\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18\x10:\tcustomers:\x03get\xa2\xb5\x18\x0eGet a customer\xaa\xb5\x18\tCustomers\x82\xd3\xe4\x93\x02\x1d\x12\x1b/v1/customers/{customer_id}\x12\xbb\x01\n\rListCustomers\x12%.tars.tenancy.v1.ListCustomersRequest\x1a&.tars.tenancy.v1.ListCustomersResponse\"[\x90\x02\x01\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18\x11:\tcustomers:\x04list\xa2\xb5\x18\x0eList customers\xaa\xb5\x18\tCustomers\x82\xd3\xe4\x93\x02\x0f\x12\r/v1/customers\x12\xc3\x01\n\x0eUpdateCustomer\x12&.tars.tenancy.v1.UpdateCustomerRequest\x1a\x19.tars.tenancy.v1.Customer\"n\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18\x13:\tcustomers:\x06update\xa2\xb5\x18\x11Update a customer\xaa\xb5\x18\tCustomers\x82\xd3\xe4\x93\x02 2\x1b/v1/customers/{customer_id}:\x01*\x12\xc1\x01\n\x0f\x41rchiveCustomer\x12\'.tars.tenancy.v1.ArchiveCustomerRequest\x1a\x16.google.protobuf.Empty\"m\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18\x14:\tcustomers:\x07\x61rchive\xa2\xb5\x18\x12\x41rchive a customer\xaa\xb5\x18\tCustomers\x82\xd3\xe4\x93\x02\x1d*\x1b/v1/customers/{customer_id}2\x84\x11\n\x0fProjectsService\x12\xc6\x01\n\rCreateProject\x12%.tars.tenancy.v1.CreateProjectRequest\x1a\x18.tars.tenancy.v1.Project\"t\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18\x12:\x08projects:\x06\x63reate\xa2\xb5\x18\x10\x43reate a project\xaa\xb5\x18\x08Projects\x82\xd3\xe4\x93\x02)\"$/v1/customers/{customer_id}/projects:\x01*\x12\xd0\x01\n\nGetProject\x12\".tars.tenancy.v1.GetProjectRequest\x1a\x18.tars.tenancy.v1.Project\"\x83\x01\x90\x02\x01\x8a\xb5\x18\x13\n\x02\x03\x01\x12\rproject_owner\x92\xb5\x18\x0f:\x08projects:\x03get\xa2\xb5\x18\rGet a project\xaa\xb5\x18\x08Projects\x82\xd3\xe4\x93\x02\x33\x12\x31/v1/customers/{customer_id}/projects/{project_id}\x12\xcc\x01\n\x0cListProjects\x12$.tars.tenancy.v1.ListProjectsRequest\x1a%.tars.tenancy.v1.ListProjectsResponse\"o\x90\x02\x01\x8a\xb5\x18\x0b\n\x02\x03\x01\x12\x05\x61\x64min\x92\xb5\x18\x10:\x08projects:\x04list\xa2\xb5\x18\rList projects\xaa\xb5\x18\x08Projects\x82\xd3\xe4\x93\x02&\x12$/v1/customers/{customer_id}/projects\x12\xdc\x01\n\rUpdateProject\x12%.tars.tenancy.v1.UpdateProjectRequest\x1a\x18.tars.tenancy.v1.Project\"\x89\x01\x8a\xb5\x18\x13\n\x02\x03\x01\x12\rproject_owner\x92\xb5\x18\x12:\x08projects:\x06update\xa2\xb5\x18\x10Update a project\xaa\xb5\x18\x08Projects\x82\xd3\xe4\x93\x02\x36\x32\x31/v1/customers/{customer_id}/projects/{project_id}:\x01*\x12\xdb\x01\n\x0e\x41rchiveProject\x12&.tars.tenancy.v1.ArchiveProjectRequest\x1a\x16.google.protobuf.Empty\"\x88\x01\x8a\xb5\x18\x13\n\x02\x03\x01\x12\rproject_owner\x92\xb5\x18\x13:\x08projects:\x07\x61rchive\xa2\xb5\x18\x11\x41rchive a project\xaa\xb5\x18\x08Projects\x82\xd3\xe4\x93\x02\x33*1/v1/customers/{customer_id}/projects/{project_id}\x12\x81\x02\n\x10\x41\x64\x64ProjectMember\x12(.tars.tenancy.v1.AddProjectMemberRequest\x1a\x1e.tars.tenancy.v1.ProjectMember\"\xa2\x01\x8a\xb5\x18\x13\n\x02\x03\x01\x12\rproject_owner\x92\xb5\x18\x18:\x08projects:\x07members:\x03\x61\x64\x64\xa2\xb5\x18\x14\x41\x64\x64 a project member\xaa\xb5\x18\x0fProject Members\x82\xd3\xe4\x93\x02>\"9/v1/customers/{customer_id}/projects/{project_id}/members:\x01*\x12\x93\x02\n\x12ListProjectMembers\x12*.tars.tenancy.v1.ListProjectMembersRequest\x1a+.tars.tenancy.v1.ListProjectMembersResponse\"\xa3\x01\x90\x02\x01\x8a\xb5\x18\x13\n\x02\x03\x01\x12\rproject_owner\x92\xb5\x18\x19:\x08projects:\x07members:\x04list\xa2\xb5\x18\x14List project members\xaa\xb5\x18\x0fProject Members\x82\xd3\xe4\x93\x02;\x12\x39/v1/customers/{customer_id}/projects/{project_id}/members\x12\x9b\x02\n\x13UpdateProjectMember\x12+.tars.tenancy.v1.UpdateProjectMemberRequest\x1a\x1e.tars.tenancy.v1.ProjectMember\"\xb6\x01\x8a\xb5\x18\x13\n\x02\x03\x01\x12\rproject_owner\x92\xb5\x18\x1b:\x08projects:\x07members:\x06update\xa2\xb5\x18\x17Update a project member\xaa\xb5\x18\x0fProject Members\x82\xd3\xe4\x93\x02L2G/v1/customers/{customer_id}/projects/{project_id}/members/{identity_id}:\x01*\x12\x90\x02\n\x13RemoveProjectMember\x12+.tars.tenancy.v1.RemoveProjectMemberRequest\x1a\x16.google.protobuf.Empty\"\xb3\x01\x8a\xb5\x18\x13\n\x02\x03\x01\x12\rproject_owner\x92\xb5\x18\x1b:\x08projects:\x07members:\x06remove\xa2\xb5\x18\x17Remove a project member\xaa\xb5\x18\x0fProject Members\x82\xd3\xe4\x93\x02I*G/v1/customers/{customer_id}/projects/{project_id}/members/{identity_id}B\xc3\x01\n\x13\x63om.tars.tenancy.v1B\x13TenancyServiceProtoP\x01Z9github.com/tetrateio/fraser/api/tars/tenancy/v1;tenancyv1\xa2\x02\x03TTX\xaa\x02\x0fTars.Tenancy.V1\xca\x02\x0fTars\\Tenancy\\V1\xe2\x02\x1bTars\\Tenancy\\V1\\GPBMetadata\xea\x02\x11Tars::Tenancy::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.tenancy.v1.tenancy_service_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\023com.tars.tenancy.v1B\023TenancyServiceProtoP\001Z9github.com/tetrateio/fraser/api/tars/tenancy/v1;tenancyv1\242\002\003TTX\252\002\017Tars.Tenancy.V1\312\002\017Tars\\Tenancy\\V1\342\002\033Tars\\Tenancy\\V1\\GPBMetadata\352\002\021Tars::Tenancy::V1'
  _globals['_CREATECUSTOMERREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_CREATECUSTOMERREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_GETCUSTOMERREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_GETCUSTOMERREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_UPDATECUSTOMERREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_UPDATECUSTOMERREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_ARCHIVECUSTOMERREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_ARCHIVECUSTOMERREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_CREATEPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_GETPROJECTREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_GETPROJECTREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_GETPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_GETPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_LISTPROJECTSREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_LISTPROJECTSREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_UPDATEPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_ARCHIVEPROJECTREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_ARCHIVEPROJECTREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_ARCHIVEPROJECTREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_ARCHIVEPROJECTREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_ADDPROJECTMEMBERREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_ADDPROJECTMEMBERREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_ADDPROJECTMEMBERREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_ADDPROJECTMEMBERREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_ADDPROJECTMEMBERREQUEST'].fields_by_name['identity_id']._loaded_options = None
  _globals['_ADDPROJECTMEMBERREQUEST'].fields_by_name['identity_id']._serialized_options = b'\340A\002'
  _globals['_ADDPROJECTMEMBERREQUEST'].fields_by_name['role']._loaded_options = None
  _globals['_ADDPROJECTMEMBERREQUEST'].fields_by_name['role']._serialized_options = b'\340A\002'
  _globals['_LISTPROJECTMEMBERSREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_LISTPROJECTMEMBERSREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_LISTPROJECTMEMBERSREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_LISTPROJECTMEMBERSREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_UPDATEPROJECTMEMBERREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_UPDATEPROJECTMEMBERREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_UPDATEPROJECTMEMBERREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_UPDATEPROJECTMEMBERREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_UPDATEPROJECTMEMBERREQUEST'].fields_by_name['identity_id']._loaded_options = None
  _globals['_UPDATEPROJECTMEMBERREQUEST'].fields_by_name['identity_id']._serialized_options = b'\340A\002'
  _globals['_UPDATEPROJECTMEMBERREQUEST'].fields_by_name['role']._loaded_options = None
  _globals['_UPDATEPROJECTMEMBERREQUEST'].fields_by_name['role']._serialized_options = b'\340A\002'
  _globals['_REMOVEPROJECTMEMBERREQUEST'].fields_by_name['customer_id']._loaded_options = None
  _globals['_REMOVEPROJECTMEMBERREQUEST'].fields_by_name['customer_id']._serialized_options = b'\340A\002'
  _globals['_REMOVEPROJECTMEMBERREQUEST'].fields_by_name['project_id']._loaded_options = None
  _globals['_REMOVEPROJECTMEMBERREQUEST'].fields_by_name['project_id']._serialized_options = b'\340A\002'
  _globals['_REMOVEPROJECTMEMBERREQUEST'].fields_by_name['identity_id']._loaded_options = None
  _globals['_REMOVEPROJECTMEMBERREQUEST'].fields_by_name['identity_id']._serialized_options = b'\340A\002'
  _globals['_TENANCYSERVICE'].methods_by_name['CreateCustomer']._loaded_options = None
  _globals['_TENANCYSERVICE'].methods_by_name['CreateCustomer']._serialized_options = b'\212\265\030\013\n\002\003\001\022\005admin\222\265\030\023:\tcustomers:\006create\242\265\030\021Create a customer\252\265\030\tCustomers\202\323\344\223\002\022\"\r/v1/customers:\001*'
  _globals['_TENANCYSERVICE'].methods_by_name['GetCustomer']._loaded_options = None
  _globals['_TENANCYSERVICE'].methods_by_name['GetCustomer']._serialized_options = b'\220\002\001\212\265\030\013\n\002\003\001\022\005admin\222\265\030\020:\tcustomers:\003get\242\265\030\016Get a customer\252\265\030\tCustomers\202\323\344\223\002\035\022\033/v1/customers/{customer_id}'
  _globals['_TENANCYSERVICE'].methods_by_name['ListCustomers']._loaded_options = None
  _globals['_TENANCYSERVICE'].methods_by_name['ListCustomers']._serialized_options = b'\220\002\001\212\265\030\013\n\002\003\001\022\005admin\222\265\030\021:\tcustomers:\004list\242\265\030\016List customers\252\265\030\tCustomers\202\323\344\223\002\017\022\r/v1/customers'
  _globals['_TENANCYSERVICE'].methods_by_name['UpdateCustomer']._loaded_options = None
  _globals['_TENANCYSERVICE'].methods_by_name['UpdateCustomer']._serialized_options = b'\212\265\030\013\n\002\003\001\022\005admin\222\265\030\023:\tcustomers:\006update\242\265\030\021Update a customer\252\265\030\tCustomers\202\323\344\223\002 2\033/v1/customers/{customer_id}:\001*'
  _globals['_TENANCYSERVICE'].methods_by_name['ArchiveCustomer']._loaded_options = None
  _globals['_TENANCYSERVICE'].methods_by_name['ArchiveCustomer']._serialized_options = b'\212\265\030\013\n\002\003\001\022\005admin\222\265\030\024:\tcustomers:\007archive\242\265\030\022Archive a customer\252\265\030\tCustomers\202\323\344\223\002\035*\033/v1/customers/{customer_id}'
  _globals['_PROJECTSSERVICE'].methods_by_name['CreateProject']._loaded_options = None
  _globals['_PROJECTSSERVICE'].methods_by_name['CreateProject']._serialized_options = b'\212\265\030\013\n\002\003\001\022\005admin\222\265\030\022:\010projects:\006create\242\265\030\020Create a project\252\265\030\010Projects\202\323\344\223\002)\"$/v1/customers/{customer_id}/projects:\001*'
  _globals['_PROJECTSSERVICE'].methods_by_name['GetProject']._loaded_options = None
  _globals['_PROJECTSSERVICE'].methods_by_name['GetProject']._serialized_options = b'\220\002\001\212\265\030\023\n\002\003\001\022\rproject_owner\222\265\030\017:\010projects:\003get\242\265\030\rGet a project\252\265\030\010Projects\202\323\344\223\0023\0221/v1/customers/{customer_id}/projects/{project_id}'
  _globals['_PROJECTSSERVICE'].methods_by_name['ListProjects']._loaded_options = None
  _globals['_PROJECTSSERVICE'].methods_by_name['ListProjects']._serialized_options = b'\220\002\001\212\265\030\013\n\002\003\001\022\005admin\222\265\030\020:\010projects:\004list\242\265\030\rList projects\252\265\030\010Projects\202\323\344\223\002&\022$/v1/customers/{customer_id}/projects'
  _globals['_PROJECTSSERVICE'].methods_by_name['UpdateProject']._loaded_options = None
  _globals['_PROJECTSSERVICE'].methods_by_name['UpdateProject']._serialized_options = b'\212\265\030\023\n\002\003\001\022\rproject_owner\222\265\030\022:\010projects:\006update\242\265\030\020Update a project\252\265\030\010Projects\202\323\344\223\002621/v1/customers/{customer_id}/projects/{project_id}:\001*'
  _globals['_PROJECTSSERVICE'].methods_by_name['ArchiveProject']._loaded_options = None
  _globals['_PROJECTSSERVICE'].methods_by_name['ArchiveProject']._serialized_options = b'\212\265\030\023\n\002\003\001\022\rproject_owner\222\265\030\023:\010projects:\007archive\242\265\030\021Archive a project\252\265\030\010Projects\202\323\344\223\0023*1/v1/customers/{customer_id}/projects/{project_id}'
  _globals['_PROJECTSSERVICE'].methods_by_name['AddProjectMember']._loaded_options = None
  _globals['_PROJECTSSERVICE'].methods_by_name['AddProjectMember']._serialized_options = b'\212\265\030\023\n\002\003\001\022\rproject_owner\222\265\030\030:\010projects:\007members:\003add\242\265\030\024Add a project member\252\265\030\017Project Members\202\323\344\223\002>\"9/v1/customers/{customer_id}/projects/{project_id}/members:\001*'
  _globals['_PROJECTSSERVICE'].methods_by_name['ListProjectMembers']._loaded_options = None
  _globals['_PROJECTSSERVICE'].methods_by_name['ListProjectMembers']._serialized_options = b'\220\002\001\212\265\030\023\n\002\003\001\022\rproject_owner\222\265\030\031:\010projects:\007members:\004list\242\265\030\024List project members\252\265\030\017Project Members\202\323\344\223\002;\0229/v1/customers/{customer_id}/projects/{project_id}/members'
  _globals['_PROJECTSSERVICE'].methods_by_name['UpdateProjectMember']._loaded_options = None
  _globals['_PROJECTSSERVICE'].methods_by_name['UpdateProjectMember']._serialized_options = b'\212\265\030\023\n\002\003\001\022\rproject_owner\222\265\030\033:\010projects:\007members:\006update\242\265\030\027Update a project member\252\265\030\017Project Members\202\323\344\223\002L2G/v1/customers/{customer_id}/projects/{project_id}/members/{identity_id}:\001*'
  _globals['_PROJECTSSERVICE'].methods_by_name['RemoveProjectMember']._loaded_options = None
  _globals['_PROJECTSSERVICE'].methods_by_name['RemoveProjectMember']._serialized_options = b'\212\265\030\023\n\002\003\001\022\rproject_owner\222\265\030\033:\010projects:\007members:\006remove\242\265\030\027Remove a project member\252\265\030\017Project Members\202\323\344\223\002I*G/v1/customers/{customer_id}/projects/{project_id}/members/{identity_id}'
  _globals['_CREATECUSTOMERREQUEST']._serialized_start=323
  _globals['_CREATECUSTOMERREQUEST']._serialized_end=453
  _globals['_GETCUSTOMERREQUEST']._serialized_start=455
  _globals['_GETCUSTOMERREQUEST']._serialized_end=513
  _globals['_LISTCUSTOMERSREQUEST']._serialized_start=515
  _globals['_LISTCUSTOMERSREQUEST']._serialized_end=586
  _globals['_LISTCUSTOMERSRESPONSE']._serialized_start=589
  _globals['_LISTCUSTOMERSRESPONSE']._serialized_end=719
  _globals['_UPDATECUSTOMERREQUEST']._serialized_start=722
  _globals['_UPDATECUSTOMERREQUEST']._serialized_end=852
  _globals['_ARCHIVECUSTOMERREQUEST']._serialized_start=854
  _globals['_ARCHIVECUSTOMERREQUEST']._serialized_end=916
  _globals['_CREATEPROJECTREQUEST']._serialized_start=919
  _globals['_CREATEPROJECTREQUEST']._serialized_end=1084
  _globals['_GETPROJECTREQUEST']._serialized_start=1086
  _globals['_GETPROJECTREQUEST']._serialized_end=1179
  _globals['_LISTPROJECTSREQUEST']._serialized_start=1181
  _globals['_LISTPROJECTSREQUEST']._serialized_end=1289
  _globals['_LISTPROJECTSRESPONSE']._serialized_start=1291
  _globals['_LISTPROJECTSRESPONSE']._serialized_end=1417
  _globals['_UPDATEPROJECTREQUEST']._serialized_start=1420
  _globals['_UPDATEPROJECTREQUEST']._serialized_end=1585
  _globals['_ARCHIVEPROJECTREQUEST']._serialized_start=1587
  _globals['_ARCHIVEPROJECTREQUEST']._serialized_end=1684
  _globals['_ADDPROJECTMEMBERREQUEST']._serialized_start=1687
  _globals['_ADDPROJECTMEMBERREQUEST']._serialized_end=1849
  _globals['_LISTPROJECTMEMBERSREQUEST']._serialized_start=1852
  _globals['_LISTPROJECTMEMBERSREQUEST']._serialized_end=2002
  _globals['_LISTPROJECTMEMBERSRESPONSE']._serialized_start=2005
  _globals['_LISTPROJECTMEMBERSRESPONSE']._serialized_end=2141
  _globals['_UPDATEPROJECTMEMBERREQUEST']._serialized_start=2144
  _globals['_UPDATEPROJECTMEMBERREQUEST']._serialized_end=2309
  _globals['_REMOVEPROJECTMEMBERREQUEST']._serialized_start=2312
  _globals['_REMOVEPROJECTMEMBERREQUEST']._serialized_end=2452
  _globals['_TENANCYSERVICE']._serialized_start=2455
  _globals['_TENANCYSERVICE']._serialized_end=3425
  _globals['_PROJECTSSERVICE']._serialized_start=3428
  _globals['_PROJECTSSERVICE']._serialized_end=5608
# @@protoc_insertion_point(module_scope)



import datetime

from buf.validate import validate_pb2 as _validate_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from tars.auth.v1 import auth_options_pb2 as _auth_options_pb2
from tars.docs.v1 import docs_pb2 as _docs_pb2
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class GetMCPProfileByURLRequest(_message.Message):
    __slots__ = ("url", "user_token")
    URL_FIELD_NUMBER: _ClassVar[int]
    USER_TOKEN_FIELD_NUMBER: _ClassVar[int]
    url: str
    user_token: str
    def __init__(self, url: _Optional[str] = ..., user_token: _Optional[str] = ...) -> None: ...

class GetMCPProfileByURLResponse(_message.Message):
    __slots__ = ("profile",)
    PROFILE_FIELD_NUMBER: _ClassVar[int]
    profile: MCPProfile
    def __init__(self, profile: _Optional[_Union[MCPProfile, _Mapping]] = ...) -> None: ...

class MCPProfile(_message.Message):
    __slots__ = ("id", "owner", "name", "description", "url", "status", "error_message", "security_policy_type", "security_policy_value", "created_at", "updated_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    OWNER_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    ERROR_MESSAGE_FIELD_NUMBER: _ClassVar[int]
    SECURITY_POLICY_TYPE_FIELD_NUMBER: _ClassVar[int]
    SECURITY_POLICY_VALUE_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    owner: str
    name: str
    description: str
    url: str
    status: str
    error_message: str
    security_policy_type: str
    security_policy_value: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., owner: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., url: _Optional[str] = ..., status: _Optional[str] = ..., error_message: _Optional[str] = ..., security_policy_type: _Optional[str] = ..., security_policy_value: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class ResolveRouteIdentityByKeyRequest(_message.Message):
    __slots__ = ("user_id", "key_id")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    KEY_ID_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    key_id: str
    def __init__(self, user_id: _Optional[str] = ..., key_id: _Optional[str] = ...) -> None: ...

class ResolveRouteIdentityByKeyResponse(_message.Message):
    __slots__ = ("effective_client_id", "route_owner_id", "route_owner_hash", "tars_id", "is_mapped_client")
    EFFECTIVE_CLIENT_ID_FIELD_NUMBER: _ClassVar[int]
    ROUTE_OWNER_ID_FIELD_NUMBER: _ClassVar[int]
    ROUTE_OWNER_HASH_FIELD_NUMBER: _ClassVar[int]
    TARS_ID_FIELD_NUMBER: _ClassVar[int]
    IS_MAPPED_CLIENT_FIELD_NUMBER: _ClassVar[int]
    effective_client_id: str
    route_owner_id: str
    route_owner_hash: str
    tars_id: str
    is_mapped_client: bool
    def __init__(self, effective_client_id: _Optional[str] = ..., route_owner_id: _Optional[str] = ..., route_owner_hash: _Optional[str] = ..., tars_id: _Optional[str] = ..., is_mapped_client: _Optional[bool] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars/insights/v1/request_logs.proto
# Protobuf Python Version: 6.32.0
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    32,
    0,
    '',
    'tars/insights/v1/request_logs.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import field_behavior_pb2 as google_dot_api_dot_field__behavior__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from tars.auth.v1 import auth_options_pb2 as tars_dot_auth_dot_v1_dot_auth__options__pb2
from tars.cli.v1 import cli_pb2 as tars_dot_cli_dot_v1_dot_cli__pb2
from tars.docs.v1 import docs_pb2 as tars_dot_docs_dot_v1_dot_docs__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#tars/insights/v1/request_logs.proto\x12\x10tars.insights.v1\x1a\x1cgoogle/api/annotations.proto\x1a\x1fgoogle/api/field_behavior.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1ftars/auth/v1/auth_options.proto\x1a\x15tars/cli/v1/cli.proto\x1a\x17tars/docs/v1/docs.proto\"\x98\x04\n\x1eListCustomerRequestLogsRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12\x1c\n\napi_key_id\x18\x03 \x01(\tR\x08\x61piKeyId\x12\x1d\n\nmodel_name\x18\x04 \x01(\tR\tmodelName\x12\x16\n\x06status\x18\x05 \x01(\tR\x06status\x12\x1f\n\x0bstatus_code\x18\x06 \x01(\x05R\nstatusCode\x12\x39\n\nstart_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12\x35\n\x08\x65nd_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x65ndTime\x12&\n\x0fmin_duration_ms\x18\t \x01(\x05R\rminDurationMs\x12&\n\x0fmax_duration_ms\x18\n \x01(\x05R\rmaxDurationMs\x12\x1b\n\tpage_size\x18\x0b \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x0c \x01(\tR\tpageToken\x12\x19\n\x08order_by\x18\r \x01(\tR\x07orderBy\x12\'\n\x0forder_direction\x18\x0e \x01(\tR\x0eorderDirection\"\x9c\x01\n\x1fListCustomerRequestLogsResponse\x12\x30\n\x04logs\x18\x01 \x03(\x0b\x32\x1c.tars.insights.v1.RequestLogR\x04logs\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1f\n\x0btotal_count\x18\x03 \x01(\x03R\ntotalCount\"\x82\x01\n\x1cGetCustomerRequestLogRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12\"\n\nrequest_id\x18\x03 \x01(\tB\x03\xe0\x41\x02R\trequestId\"\xa7\x02\n!GetCustomerRequestLogStatsRequest\x12\x1f\n\x0b\x63ustomer_id\x18\x01 \x01(\tR\ncustomerId\x12\x1d\n\nproject_id\x18\x02 \x01(\tR\tprojectId\x12\x1d\n\nmodel_name\x18\x03 \x01(\tR\tmodelName\x12\x39\n\nstart_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12\x35\n\x08\x65nd_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x65ndTime\x12\x19\n\x08group_by\x18\x06 \x01(\tR\x07groupBy\x12\x16\n\x06metric\x18\x07 \x01(\tR\x06metric\"\xea\x03\n\x17QueryRequestLogsRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x1c\n\napi_key_id\x18\x02 \x01(\tR\x08\x61piKeyId\x12\x1d\n\nmodel_name\x18\x03 \x01(\tR\tmodelName\x12\x16\n\x06status\x18\x04 \x01(\tR\x06status\x12\x1f\n\x0bstatus_code\x18\x05 \x01(\x05R\nstatusCode\x12\x39\n\nstart_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12\x35\n\x08\x65nd_time\x18\x07 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x65ndTime\x12&\n\x0fmin_duration_ms\x18\x08 \x01(\x05R\rminDurationMs\x12&\n\x0fmax_duration_ms\x18\t \x01(\x05R\rmaxDurationMs\x12\x1b\n\tpage_size\x18\n \x01(\x05R\x08pageSize\x12\x1d\n\npage_token\x18\x0b \x01(\tR\tpageToken\x12\x19\n\x08order_by\x18\x0c \x01(\tR\x07orderBy\x12\'\n\x0forder_direction\x18\r \x01(\tR\x0eorderDirection\"\x95\x01\n\x18QueryRequestLogsResponse\x12\x30\n\x04logs\x18\x01 \x03(\x0b\x32\x1c.tars.insights.v1.RequestLogR\x04logs\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\x12\x1f\n\x0btotal_count\x18\x03 \x01(\x03R\ntotalCount\"5\n\x14GetRequestLogRequest\x12\x1d\n\nrequest_id\x18\x01 \x01(\tR\trequestId\"\xeb\x0e\n\nRequestLog\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\x12\x38\n\ttimestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\ttimestamp\x12\x17\n\x07user_id\x18\x03 \x01(\tR\x06userId\x12\x1c\n\napi_key_id\x18\x04 \x01(\tR\x08\x61piKeyId\x12$\n\x0e\x61pi_key_prefix\x18\x05 \x01(\tR\x0c\x61piKeyPrefix\x12 \n\x0c\x61pi_key_hash\x18\x06 \x01(\tR\napiKeyHash\x12&\n\x0f\x61pi_key_address\x18\x07 \x01(\tR\rapiKeyAddress\x12 \n\x0c\x61pi_key_name\x18\x08 \x01(\tR\napiKeyName\x12\x1d\n\nmodel_name\x18\t \x01(\tR\tmodelName\x12!\n\x0cinput_tokens\x18\n \x01(\x05R\x0binputTokens\x12#\n\routput_tokens\x18\x0b \x01(\x05R\x0coutputTokens\x12\x41\n\x1dinput_tokens_cost_microdollar\x18\x0c \x01(\x03R\x1ainputTokensCostMicrodollar\x12*\n\x11input_tokens_cost\x18\r \x01(\tR\x0finputTokensCost\x12>\n\x1cinput_tokens_cost_before_fee\x18\x0e \x01(\tR\x18inputTokensCostBeforeFee\x12\x43\n\x1eoutput_tokens_cost_microdollar\x18\x0f \x01(\x03R\x1boutputTokensCostMicrodollar\x12,\n\x12output_tokens_cost\x18\x10 \x01(\tR\x10outputTokensCost\x12@\n\x1doutput_tokens_cost_before_fee\x18\x11 \x01(\tR\x19outputTokensCostBeforeFee\x12\x16\n\x06status\x18\x12 \x01(\tR\x06status\x12\x1f\n\x0bstatus_code\x18\x13 \x01(\x05R\nstatusCode\x12@\n\x0frequest_headers\x18\x14 \x01(\x0b\x32\x17.google.protobuf.StructR\x0erequestHeaders\x12:\n\x0crequest_body\x18\x15 \x01(\x0b\x32\x17.google.protobuf.StructR\x0brequestBody\x12\x42\n\x10response_headers\x18\x16 \x01(\x0b\x32\x17.google.protobuf.StructR\x0fresponseHeaders\x12#\n\rresponse_body\x18\x17 \x01(\tR\x0cresponseBody\x12*\n\x11response_body_raw\x18\x18 \x01(\x0cR\x0fresponseBodyRaw\x12>\n\x0ellm_parameters\x18\x19 \x01(\x0b\x32\x17.google.protobuf.StructR\rllmParameters\x12\x30\n\x14upstream_duration_ms\x18\x1a \x01(\x05R\x12upstreamDurationMs\x12\x1f\n\x0b\x64uration_ms\x18\x1b \x01(\x05R\ndurationMs\x12\x1d\n\nrequest_id\x18\x1c \x01(\tR\trequestId\x12\x39\n\ncreated_at\x18\x1d \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tcreatedAt\x12)\n\x10storage_location\x18\x1e \x01(\tR\x0fstorageLocation\x12*\n\x11storage_row_index\x18\x1f \x01(\x05R\x0fstorageRowIndex\x12(\n\x10storage_batch_id\x18  \x01(\tR\x0estorageBatchId\x12,\n\x12use_object_storage\x18! \x01(\x08R\x10useObjectStorage\x12.\n\x13\x63\x61\x63hed_input_tokens\x18\" \x01(\x05R\x11\x63\x61\x63hedInputTokens\x12\x37\n\x18\x63\x61\x63hed_input_tokens_cost\x18# \x01(\tR\x15\x63\x61\x63hedInputTokensCost\x12K\n#cached_input_tokens_cost_before_fee\x18$ \x01(\tR\x1e\x63\x61\x63hedInputTokensCostBeforeFee\x12=\n\x1b\x63\x61\x63he_creation_input_tokens\x18% \x01(\x05R\x18\x63\x61\x63heCreationInputTokens\x12\x46\n cache_creation_input_tokens_cost\x18& \x01(\tR\x1c\x63\x61\x63heCreationInputTokensCost\x12Z\n+cache_creation_input_tokens_cost_before_fee\x18\' \x01(\tR%cacheCreationInputTokensCostBeforeFee\"\xf8\x01\n\x19GetRequestLogStatsRequest\x12\x17\n\x07user_id\x18\x01 \x01(\tR\x06userId\x12\x1d\n\nmodel_name\x18\x02 \x01(\tR\tmodelName\x12\x39\n\nstart_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\tstartTime\x12\x35\n\x08\x65nd_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x07\x65ndTime\x12\x19\n\x08group_by\x18\x05 \x01(\tR\x07groupBy\x12\x16\n\x06metric\x18\x06 \x01(\tR\x06metric\"\xb3\x02\n\x17RequestLogStatsResponse\x12\x31\n\x05stats\x18\x01 \x03(\x0b\x32\x1b.tars.insights.v1.StatEntryR\x05stats\x12\x1f\n\x0btotal_count\x18\x02 \x01(\x03R\ntotalCount\x12,\n\x12total_input_tokens\x18\x03 \x01(\x03R\x10totalInputTokens\x12.\n\x13total_output_tokens\x18\x04 \x01(\x03R\x11totalOutputTokens\x12\x1d\n\ntotal_cost\x18\x05 \x01(\tR\ttotalCost\x12&\n\x0f\x61vg_duration_ms\x18\x06 \x01(\x01R\ravgDurationMs\x12\x1f\n\x0b\x65rror_count\x18\x07 \x01(\x03R\nerrorCount\"\xee\x03\n\tStatEntry\x12\x10\n\x03key\x18\x01 \x01(\tR\x03key\x12\x14\n\x05\x63ount\x18\x02 \x01(\x03R\x05\x63ount\x12\x1f\n\x0b\x65rror_count\x18\x03 \x01(\x03R\nerrorCount\x12!\n\x0cinput_tokens\x18\x04 \x01(\x03R\x0binputTokens\x12#\n\routput_tokens\x18\x05 \x01(\x03R\x0coutputTokens\x12!\n\x0ctotal_tokens\x18\x06 \x01(\x03R\x0btotalTokens\x12\x12\n\x04\x63ost\x18\x07 \x01(\tR\x04\x63ost\x12)\n\x10\x63ost_microdollar\x18\x08 \x01(\x03R\x0f\x63ostMicrodollar\x12&\n\x0f\x61vg_duration_ms\x18\t \x01(\x03R\ravgDurationMs\x12&\n\x0fmin_duration_ms\x18\n \x01(\x03R\rminDurationMs\x12&\n\x0fmax_duration_ms\x18\x0b \x01(\x03R\rmaxDurationMs\x12&\n\x0fp50_duration_ms\x18\x0c \x01(\x03R\rp50DurationMs\x12&\n\x0fp95_duration_ms\x18\r \x01(\x03R\rp95DurationMs\x12&\n\x0fp99_duration_ms\x18\x0e \x01(\x03R\rp99DurationMs2\x8f\x07\n\x1a\x43ustomerRequestLogsService\x12\xac\x02\n\x17ListCustomerRequestLogs\x12\x30.tars.insights.v1.ListCustomerRequestLogsRequest\x1a\x31.tars.insights.v1.ListCustomerRequestLogsResponse\"\xab\x01\x90\x02\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x16:\x08insights:\x04logs:\x04list\xa2\xb5\x18,List request logs scoped to the calling user\xaa\xb5\x18\x0cRequest Logs\x82\xd3\xe4\x93\x02@\x12>/v1/customers/{customer_id}/projects/{project_id}/request-logs\x12\x8b\x02\n\x15GetCustomerRequestLog\x12..tars.insights.v1.GetCustomerRequestLogRequest\x1a\x1c.tars.insights.v1.RequestLog\"\xa3\x01\x90\x02\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x15:\x08insights:\x04logs:\x03get\xa2\xb5\x18\x18Get a single request log\xaa\xb5\x18\x0cRequest Logs\x82\xd3\xe4\x93\x02M\x12K/v1/customers/{customer_id}/projects/{project_id}/request-logs/{request_id}\x12\xb3\x02\n\x1aGetCustomerRequestLogStats\x12\x33.tars.insights.v1.GetCustomerRequestLogStatsRequest\x1a).tars.insights.v1.RequestLogStatsResponse\"\xb4\x01\x90\x02\x01\x8a\xb5\x18\x04\n\x02\x03\x01\x92\xb5\x18\x17:\x08insights:\x04logs:\x05stats\xa2\xb5\x18.Aggregate stats over the caller\'s request logs\xaa\xb5\x18\x0cRequest Logs\x82\xd3\xe4\x93\x02\x46\x12\x44/v1/customers/{customer_id}/projects/{project_id}/request-logs/stats2\x8b\x04\n\x12RequestLogsService\x12\xa4\x01\n\x10QueryRequestLogs\x12).tars.insights.v1.QueryRequestLogsRequest\x1a*.tars.insights.v1.QueryRequestLogsResponse\"9\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x0cRequest Logs\x82\xd3\xe4\x93\x02\x12\x12\x10/v1/request-logs\x12\x9d\x01\n\rGetRequestLog\x12&.tars.insights.v1.GetRequestLogRequest\x1a\x1c.tars.insights.v1.RequestLog\"F\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x0cRequest Logs\x82\xd3\xe4\x93\x02\x1f\x12\x1d/v1/request-logs/{request_id}\x12\xad\x01\n\x12GetRequestLogStats\x12+.tars.insights.v1.GetRequestLogStatsRequest\x1a).tars.insights.v1.RequestLogStatsResponse\"?\x90\x02\x01\x8a\xb5\x18\n\n\x01\x01\x12\x05\x61\x64min\xaa\xb5\x18\x0cRequest Logs\x82\xd3\xe4\x93\x02\x18\x12\x16/v1/request-logs/statsB\xc7\x01\n\x14\x63om.tars.insights.v1B\x10RequestLogsProtoP\x01Z;github.com/tetrateio/fraser/api/tars/insights/v1;insightsv1\xa2\x02\x03TIX\xaa\x02\x10Tars.Insights.V1\xca\x02\x10Tars\\Insights\\V1\xe2\x02\x1cTars\\Insights\\V1\\GPBMetadata\xea\x02\x12Tars::Insights::V1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars.insights.v1.request_logs_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  _globals['DESCRIPTOR']._loaded_options = None
  _globals['DESCRIPTOR']._serialized_options = b'\n\024com.tars.insights.v1B\020RequestLogsProtoP\001Z;github.com/tetrateio/fraser/api/tars/insights/v1;insightsv1\242\002\003TIX\252\002\020Tars.Insights.V1\312\002\020Tars\\Insights\\V1\342\002\034Tars\\Insights\\V1\\GPBMetadata\352\002\022Tars::Insights::V1'
  _globals['_GETCUSTOMERREQUESTLOGREQUEST'].fields_by_name['request_id']._loaded_options = None
  _globals['_GETCUSTOMERREQUESTLOGREQUEST'].fields_by_name['request_id']._serialized_options = b'\340A\002'
  _globals['_CUSTOMERREQUESTLOGSSERVICE'].methods_by_name['ListCustomerRequestLogs']._loaded_options = None
  _globals['_CUSTOMERREQUESTLOGSSERVICE'].methods_by_name['ListCustomerRequestLogs']._serialized_options = b'\220\002\001\212\265\030\004\n\002\003\001\222\265\030\026:\010insights:\004logs:\004list\242\265\030,List request logs scoped to the calling user\252\265\030\014Request Logs\202\323\344\223\002@\022>/v1/customers/{customer_id}/projects/{project_id}/request-logs'
  _globals['_CUSTOMERREQUESTLOGSSERVICE'].methods_by_name['GetCustomerRequestLog']._loaded_options = None
  _globals['_CUSTOMERREQUESTLOGSSERVICE'].methods_by_name['GetCustomerRequestLog']._serialized_options = b'\220\002\001\212\265\030\004\n\002\003\001\222\265\030\025:\010insights:\004logs:\003get\242\265\030\030Get a single request log\252\265\030\014Request Logs\202\323\344\223\002M\022K/v1/customers/{customer_id}/projects/{project_id}/request-logs/{request_id}'
  _globals['_CUSTOMERREQUESTLOGSSERVICE'].methods_by_name['GetCustomerRequestLogStats']._loaded_options = None
  _globals['_CUSTOMERREQUESTLOGSSERVICE'].methods_by_name['GetCustomerRequestLogStats']._serialized_options = b'\220\002\001\212\265\030\004\n\002\003\001\222\265\030\027:\010insights:\004logs:\005stats\242\265\030.Aggregate stats over the caller\'s request logs\252\265\030\014Request Logs\202\323\344\223\002F\022D/v1/customers/{customer_id}/projects/{project_id}/request-logs/stats'
  _globals['_REQUESTLOGSSERVICE'].methods_by_name['QueryRequestLogs']._loaded_options = None
  _globals['_REQUESTLOGSSERVICE'].methods_by_name['QueryRequestLogs']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\014Request Logs\202\323\344\223\002\022\022\020/v1/request-logs'
  _globals['_REQUESTLOGSSERVICE'].methods_by_name['GetRequestLog']._loaded_options = None
  _globals['_REQUESTLOGSSERVICE'].methods_by_name['GetRequestLog']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\014Request Logs\202\323\344\223\002\037\022\035/v1/request-logs/{request_id}'
  _globals['_REQUESTLOGSSERVICE'].methods_by_name['GetRequestLogStats']._loaded_options = None
  _globals['_REQUESTLOGSSERVICE'].methods_by_name['GetRequestLogStats']._serialized_options = b'\220\002\001\212\265\030\n\n\001\001\022\005admin\252\265\030\014Request Logs\202\323\344\223\002\030\022\026/v1/request-logs/stats'
  _globals['_LISTCUSTOMERREQUESTLOGSREQUEST']._serialized_start=265
  _globals['_LISTCUSTOMERREQUESTLOGSREQUEST']._serialized_end=801
  _globals['_LISTCUSTOMERREQUESTLOGSRESPONSE']._serialized_start=804
  _globals['_LISTCUSTOMERREQUESTLOGSRESPONSE']._serialized_end=960
  _globals['_GETCUSTOMERREQUESTLOGREQUEST']._serialized_start=963
  _globals['_GETCUSTOMERREQUESTLOGREQUEST']._serialized_end=1093
  _globals['_GETCUSTOMERREQUESTLOGSTATSREQUEST']._serialized_start=1096
  _globals['_GETCUSTOMERREQUESTLOGSTATSREQUEST']._serialized_end=1391
  _globals['_QUERYREQUESTLOGSREQUEST']._serialized_start=1394
  _globals['_QUERYREQUESTLOGSREQUEST']._serialized_end=1884
  _globals['_QUERYREQUESTLOGSRESPONSE']._serialized_start=1887
  _globals['_QUERYREQUESTLOGSRESPONSE']._serialized_end=2036
  _globals['_GETREQUESTLOGREQUEST']._serialized_start=2038
  _globals['_GETREQUESTLOGREQUEST']._serialized_end=2091
  _globals['_REQUESTLOG']._serialized_start=2094
  _globals['_REQUESTLOG']._serialized_end=3993
  _globals['_GETREQUESTLOGSTATSREQUEST']._serialized_start=3996
  _globals['_GETREQUESTLOGSTATSREQUEST']._serialized_end=4244
  _globals['_REQUESTLOGSTATSRESPONSE']._serialized_start=4247
  _globals['_REQUESTLOGSTATSRESPONSE']._serialized_end=4554
  _globals['_STATENTRY']._serialized_start=4557
  _globals['_STATENTRY']._serialized_end=5051
  _globals['_CUSTOMERREQUESTLOGSSERVICE']._serialized_start=5054
  _globals['_CUSTOMERREQUESTLOGSSERVICE']._serialized_end=5965
  _globals['_REQUESTLOGSSERVICE']._serialized_start=5968
  _globals['_REQUESTLOGSSERVICE']._serialized_end=6491
# @@protoc_insertion_point(module_scope)



import datetime

from buf.validate import validate_pb2 as _validate_pb2
from google.api import annotations_pb2 as _annotations_pb2
from google.protobuf import timestamp_pb2 as _timestamp_pb2
from tars.auth.v1 import auth_options_pb2 as _auth_options_pb2
from tars.docs.v1 import docs_pb2 as _docs_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf.internal import enum_type_wrapper as _enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from collections.abc import Iterable as _Iterable, Mapping as _Mapping
from typing import ClassVar as _ClassVar, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class ServiceAccountStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    SERVICE_ACCOUNT_STATUS_UNSPECIFIED: _ClassVar[ServiceAccountStatus]
    SERVICE_ACCOUNT_STATUS_ACTIVE: _ClassVar[ServiceAccountStatus]
    SERVICE_ACCOUNT_STATUS_REVOKED: _ClassVar[ServiceAccountStatus]
    SERVICE_ACCOUNT_STATUS_EXPIRED: _ClassVar[ServiceAccountStatus]

class UserTokenStatus(int, metaclass=_enum_type_wrapper.EnumTypeWrapper):
    __slots__ = ()
    USER_TOKEN_STATUS_UNSPECIFIED: _ClassVar[UserTokenStatus]
    USER_TOKEN_STATUS_ACTIVE: _ClassVar[UserTokenStatus]
    USER_TOKEN_STATUS_REVOKED: _ClassVar[UserTokenStatus]
    USER_TOKEN_STATUS_EXPIRED: _ClassVar[UserTokenStatus]
SERVICE_ACCOUNT_STATUS_UNSPECIFIED: ServiceAccountStatus
SERVICE_ACCOUNT_STATUS_ACTIVE: ServiceAccountStatus
SERVICE_ACCOUNT_STATUS_REVOKED: ServiceAccountStatus
SERVICE_ACCOUNT_STATUS_EXPIRED: ServiceAccountStatus
USER_TOKEN_STATUS_UNSPECIFIED: UserTokenStatus
USER_TOKEN_STATUS_ACTIVE: UserTokenStatus
USER_TOKEN_STATUS_REVOKED: UserTokenStatus
USER_TOKEN_STATUS_EXPIRED: UserTokenStatus

class PingRequest(_message.Message):
    __slots__ = ()
    def __init__(self) -> None: ...

class PingResponse(_message.Message):
    __slots__ = ("message", "timestamp")
    MESSAGE_FIELD_NUMBER: _ClassVar[int]
    TIMESTAMP_FIELD_NUMBER: _ClassVar[int]
    message: str
    timestamp: _timestamp_pb2.Timestamp
    def __init__(self, message: _Optional[str] = ..., timestamp: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class CreateWorkspaceRequest(_message.Message):
    __slots__ = ("customer_id", "workspace_id", "name", "description", "labels", "project_id")
    class LabelsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    workspace_id: str
    name: str
    description: str
    labels: _containers.ScalarMap[str, str]
    project_id: str
    def __init__(self, customer_id: _Optional[str] = ..., workspace_id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., labels: _Optional[_Mapping[str, str]] = ..., project_id: _Optional[str] = ...) -> None: ...

class CreateWorkspaceResponse(_message.Message):
    __slots__ = ("workspace",)
    WORKSPACE_FIELD_NUMBER: _ClassVar[int]
    workspace: Workspace
    def __init__(self, workspace: _Optional[_Union[Workspace, _Mapping]] = ...) -> None: ...

class ListWorkspacesRequest(_message.Message):
    __slots__ = ("customer_id", "page_size", "page_token")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    page_size: int
    page_token: str
    def __init__(self, customer_id: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class ListWorkspacesResponse(_message.Message):
    __slots__ = ("workspaces", "next_page_token")
    WORKSPACES_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    workspaces: _containers.RepeatedCompositeFieldContainer[Workspace]
    next_page_token: str
    def __init__(self, workspaces: _Optional[_Iterable[_Union[Workspace, _Mapping]]] = ..., next_page_token: _Optional[str] = ...) -> None: ...

class GetWorkspaceRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetWorkspaceResponse(_message.Message):
    __slots__ = ("workspace",)
    WORKSPACE_FIELD_NUMBER: _ClassVar[int]
    workspace: Workspace
    def __init__(self, workspace: _Optional[_Union[Workspace, _Mapping]] = ...) -> None: ...

class UpdateWorkspaceRequest(_message.Message):
    __slots__ = ("id", "name", "description", "labels")
    class LabelsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    id: str
    name: str
    description: str
    labels: _containers.ScalarMap[str, str]
    def __init__(self, id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., labels: _Optional[_Mapping[str, str]] = ...) -> None: ...

class UpdateWorkspaceResponse(_message.Message):
    __slots__ = ("workspace",)
    WORKSPACE_FIELD_NUMBER: _ClassVar[int]
    workspace: Workspace
    def __init__(self, workspace: _Optional[_Union[Workspace, _Mapping]] = ...) -> None: ...

class SetWorkspaceProjectRequest(_message.Message):
    __slots__ = ("id", "project_id")
    ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    project_id: str
    def __init__(self, id: _Optional[str] = ..., project_id: _Optional[str] = ...) -> None: ...

class SetWorkspaceProjectResponse(_message.Message):
    __slots__ = ("workspace",)
    WORKSPACE_FIELD_NUMBER: _ClassVar[int]
    workspace: Workspace
    def __init__(self, workspace: _Optional[_Union[Workspace, _Mapping]] = ...) -> None: ...

class SetWorkspaceURLRequest(_message.Message):
    __slots__ = ("id", "url", "trigger_update")
    ID_FIELD_NUMBER: _ClassVar[int]
    URL_FIELD_NUMBER: _ClassVar[int]
    TRIGGER_UPDATE_FIELD_NUMBER: _ClassVar[int]
    id: str
    url: str
    trigger_update: bool
    def __init__(self, id: _Optional[str] = ..., url: _Optional[str] = ..., trigger_update: _Optional[bool] = ...) -> None: ...

class SetWorkspaceURLResponse(_message.Message):
    __slots__ = ("workspace",)
    WORKSPACE_FIELD_NUMBER: _ClassVar[int]
    workspace: Workspace
    def __init__(self, workspace: _Optional[_Union[Workspace, _Mapping]] = ...) -> None: ...

class DeleteWorkspaceRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteWorkspaceResponse(_message.Message):
    __slots__ = ("success", "deleted_at")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    DELETED_AT_FIELD_NUMBER: _ClassVar[int]
    success: bool
    deleted_at: _timestamp_pb2.Timestamp
    def __init__(self, success: _Optional[bool] = ..., deleted_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class Workspace(_message.Message):
    __slots__ = ("id", "customer_id", "workspace_id", "name", "description", "labels", "created_at", "updated_at", "deleted_at", "project_id")
    class LabelsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    DELETED_AT_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    customer_id: str
    workspace_id: str
    name: str
    description: str
    labels: _containers.ScalarMap[str, str]
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    deleted_at: _timestamp_pb2.Timestamp
    project_id: str
    def __init__(self, id: _Optional[str] = ..., customer_id: _Optional[str] = ..., workspace_id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., labels: _Optional[_Mapping[str, str]] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., deleted_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., project_id: _Optional[str] = ...) -> None: ...

class CreateServiceAccountRequest(_message.Message):
    __slots__ = ("customer_id", "workspace_id", "validity_days", "api_uri", "serve_url", "issuer", "audience", "jwks_uri", "telemetry_endpoint", "telemetry_protocol", "telemetry_insecure", "telemetry_timeout", "telemetry_headers", "scopes", "router_url", "router_key", "internal_api_key", "telemetry_local_vars")
    class TelemetryHeadersEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    class TelemetryLocalVarsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    VALIDITY_DAYS_FIELD_NUMBER: _ClassVar[int]
    API_URI_FIELD_NUMBER: _ClassVar[int]
    SERVE_URL_FIELD_NUMBER: _ClassVar[int]
    ISSUER_FIELD_NUMBER: _ClassVar[int]
    AUDIENCE_FIELD_NUMBER: _ClassVar[int]
    JWKS_URI_FIELD_NUMBER: _ClassVar[int]
    TELEMETRY_ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    TELEMETRY_PROTOCOL_FIELD_NUMBER: _ClassVar[int]
    TELEMETRY_INSECURE_FIELD_NUMBER: _ClassVar[int]
    TELEMETRY_TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    TELEMETRY_HEADERS_FIELD_NUMBER: _ClassVar[int]
    SCOPES_FIELD_NUMBER: _ClassVar[int]
    ROUTER_URL_FIELD_NUMBER: _ClassVar[int]
    ROUTER_KEY_FIELD_NUMBER: _ClassVar[int]
    INTERNAL_API_KEY_FIELD_NUMBER: _ClassVar[int]
    TELEMETRY_LOCAL_VARS_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    workspace_id: str
    validity_days: int
    api_uri: str
    serve_url: str
    issuer: str
    audience: str
    jwks_uri: str
    telemetry_endpoint: str
    telemetry_protocol: str
    telemetry_insecure: bool
    telemetry_timeout: str
    telemetry_headers: _containers.ScalarMap[str, str]
    scopes: _containers.RepeatedScalarFieldContainer[str]
    router_url: str
    router_key: str
    internal_api_key: str
    telemetry_local_vars: _containers.ScalarMap[str, str]
    def __init__(self, customer_id: _Optional[str] = ..., workspace_id: _Optional[str] = ..., validity_days: _Optional[int] = ..., api_uri: _Optional[str] = ..., serve_url: _Optional[str] = ..., issuer: _Optional[str] = ..., audience: _Optional[str] = ..., jwks_uri: _Optional[str] = ..., telemetry_endpoint: _Optional[str] = ..., telemetry_protocol: _Optional[str] = ..., telemetry_insecure: _Optional[bool] = ..., telemetry_timeout: _Optional[str] = ..., telemetry_headers: _Optional[_Mapping[str, str]] = ..., scopes: _Optional[_Iterable[str]] = ..., router_url: _Optional[str] = ..., router_key: _Optional[str] = ..., internal_api_key: _Optional[str] = ..., telemetry_local_vars: _Optional[_Mapping[str, str]] = ...) -> None: ...

class CreateServiceAccountResponse(_message.Message):
    __slots__ = ("service_account", "checksum", "checksum_algorithm")
    SERVICE_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    CHECKSUM_FIELD_NUMBER: _ClassVar[int]
    CHECKSUM_ALGORITHM_FIELD_NUMBER: _ClassVar[int]
    service_account: ServiceAccount
    checksum: str
    checksum_algorithm: str
    def __init__(self, service_account: _Optional[_Union[ServiceAccount, _Mapping]] = ..., checksum: _Optional[str] = ..., checksum_algorithm: _Optional[str] = ...) -> None: ...

class ServiceAccount(_message.Message):
    __slots__ = ("id", "type", "customer_id", "workspace_id", "client_email", "private_key_id", "private_key", "api_uri", "serve_url", "auth_server", "gatekeeper", "data_exports", "scopes", "created_at", "expires_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    TYPE_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    CLIENT_EMAIL_FIELD_NUMBER: _ClassVar[int]
    PRIVATE_KEY_ID_FIELD_NUMBER: _ClassVar[int]
    PRIVATE_KEY_FIELD_NUMBER: _ClassVar[int]
    API_URI_FIELD_NUMBER: _ClassVar[int]
    SERVE_URL_FIELD_NUMBER: _ClassVar[int]
    AUTH_SERVER_FIELD_NUMBER: _ClassVar[int]
    GATEKEEPER_FIELD_NUMBER: _ClassVar[int]
    DATA_EXPORTS_FIELD_NUMBER: _ClassVar[int]
    SCOPES_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    type: str
    customer_id: str
    workspace_id: str
    client_email: str
    private_key_id: str
    private_key: str
    api_uri: str
    serve_url: str
    auth_server: AuthServerConfig
    gatekeeper: GatekeeperConfig
    data_exports: DataExportsConfig
    scopes: _containers.RepeatedScalarFieldContainer[str]
    created_at: _timestamp_pb2.Timestamp
    expires_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., type: _Optional[str] = ..., customer_id: _Optional[str] = ..., workspace_id: _Optional[str] = ..., client_email: _Optional[str] = ..., private_key_id: _Optional[str] = ..., private_key: _Optional[str] = ..., api_uri: _Optional[str] = ..., serve_url: _Optional[str] = ..., auth_server: _Optional[_Union[AuthServerConfig, _Mapping]] = ..., gatekeeper: _Optional[_Union[GatekeeperConfig, _Mapping]] = ..., data_exports: _Optional[_Union[DataExportsConfig, _Mapping]] = ..., scopes: _Optional[_Iterable[str]] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., expires_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class AuthServerConfig(_message.Message):
    __slots__ = ("issuer", "audience", "jwks_uri", "public_keys")
    ISSUER_FIELD_NUMBER: _ClassVar[int]
    AUDIENCE_FIELD_NUMBER: _ClassVar[int]
    JWKS_URI_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEYS_FIELD_NUMBER: _ClassVar[int]
    issuer: str
    audience: str
    jwks_uri: str
    public_keys: _containers.RepeatedCompositeFieldContainer[PublicKey]
    def __init__(self, issuer: _Optional[str] = ..., audience: _Optional[str] = ..., jwks_uri: _Optional[str] = ..., public_keys: _Optional[_Iterable[_Union[PublicKey, _Mapping]]] = ...) -> None: ...

class GatekeeperConfig(_message.Message):
    __slots__ = ("issuer", "audience", "public_keys", "router")
    ISSUER_FIELD_NUMBER: _ClassVar[int]
    AUDIENCE_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEYS_FIELD_NUMBER: _ClassVar[int]
    ROUTER_FIELD_NUMBER: _ClassVar[int]
    issuer: str
    audience: str
    public_keys: _containers.RepeatedCompositeFieldContainer[PublicKey]
    router: RouterConfig
    def __init__(self, issuer: _Optional[str] = ..., audience: _Optional[str] = ..., public_keys: _Optional[_Iterable[_Union[PublicKey, _Mapping]]] = ..., router: _Optional[_Union[RouterConfig, _Mapping]] = ...) -> None: ...

class RouterConfig(_message.Message):
    __slots__ = ("url", "key")
    URL_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    url: str
    key: str
    def __init__(self, url: _Optional[str] = ..., key: _Optional[str] = ...) -> None: ...

class PublicKey(_message.Message):
    __slots__ = ("kid", "alg", "use", "key")
    KID_FIELD_NUMBER: _ClassVar[int]
    ALG_FIELD_NUMBER: _ClassVar[int]
    USE_FIELD_NUMBER: _ClassVar[int]
    KEY_FIELD_NUMBER: _ClassVar[int]
    kid: str
    alg: str
    use: str
    key: str
    def __init__(self, kid: _Optional[str] = ..., alg: _Optional[str] = ..., use: _Optional[str] = ..., key: _Optional[str] = ...) -> None: ...

class DataExportsConfig(_message.Message):
    __slots__ = ("telemetry",)
    TELEMETRY_FIELD_NUMBER: _ClassVar[int]
    telemetry: TelemetryConfig
    def __init__(self, telemetry: _Optional[_Union[TelemetryConfig, _Mapping]] = ...) -> None: ...

class TelemetryConfig(_message.Message):
    __slots__ = ("endpoint", "protocol", "insecure", "timeout", "headers")
    class HeadersEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ENDPOINT_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_FIELD_NUMBER: _ClassVar[int]
    INSECURE_FIELD_NUMBER: _ClassVar[int]
    TIMEOUT_FIELD_NUMBER: _ClassVar[int]
    HEADERS_FIELD_NUMBER: _ClassVar[int]
    endpoint: str
    protocol: str
    insecure: bool
    timeout: str
    headers: _containers.ScalarMap[str, str]
    def __init__(self, endpoint: _Optional[str] = ..., protocol: _Optional[str] = ..., insecure: _Optional[bool] = ..., timeout: _Optional[str] = ..., headers: _Optional[_Mapping[str, str]] = ...) -> None: ...

class ListServiceAccountsRequest(_message.Message):
    __slots__ = ("customer_id", "workspace_id", "status", "page_size", "page_token")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    workspace_id: str
    status: ServiceAccountStatus
    page_size: int
    page_token: str
    def __init__(self, customer_id: _Optional[str] = ..., workspace_id: _Optional[str] = ..., status: _Optional[_Union[ServiceAccountStatus, str]] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class ListServiceAccountsResponse(_message.Message):
    __slots__ = ("service_accounts", "next_page_token")
    SERVICE_ACCOUNTS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    service_accounts: _containers.RepeatedCompositeFieldContainer[ServiceAccountInfo]
    next_page_token: str
    def __init__(self, service_accounts: _Optional[_Iterable[_Union[ServiceAccountInfo, _Mapping]]] = ..., next_page_token: _Optional[str] = ...) -> None: ...

class GetServiceAccountRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetServiceAccountResponse(_message.Message):
    __slots__ = ("service_account",)
    SERVICE_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    service_account: ServiceAccountInfo
    def __init__(self, service_account: _Optional[_Union[ServiceAccountInfo, _Mapping]] = ...) -> None: ...

class ServiceAccountInfo(_message.Message):
    __slots__ = ("id", "customer_id", "workspace_id", "email", "status", "created_at", "expires_at", "last_used_at", "public_key_fingerprint", "metadata", "revoked_at")
    class MetadataEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    EMAIL_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    LAST_USED_AT_FIELD_NUMBER: _ClassVar[int]
    PUBLIC_KEY_FINGERPRINT_FIELD_NUMBER: _ClassVar[int]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    REVOKED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    customer_id: str
    workspace_id: str
    email: str
    status: ServiceAccountStatus
    created_at: _timestamp_pb2.Timestamp
    expires_at: _timestamp_pb2.Timestamp
    last_used_at: _timestamp_pb2.Timestamp
    public_key_fingerprint: str
    metadata: _containers.ScalarMap[str, str]
    revoked_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., customer_id: _Optional[str] = ..., workspace_id: _Optional[str] = ..., email: _Optional[str] = ..., status: _Optional[_Union[ServiceAccountStatus, str]] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., expires_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., last_used_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., public_key_fingerprint: _Optional[str] = ..., metadata: _Optional[_Mapping[str, str]] = ..., revoked_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class RevokeServiceAccountRequest(_message.Message):
    __slots__ = ("id", "reason")
    ID_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    id: str
    reason: str
    def __init__(self, id: _Optional[str] = ..., reason: _Optional[str] = ...) -> None: ...

class RevokeServiceAccountResponse(_message.Message):
    __slots__ = ("success", "revoked_at")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    REVOKED_AT_FIELD_NUMBER: _ClassVar[int]
    success: bool
    revoked_at: _timestamp_pb2.Timestamp
    def __init__(self, success: _Optional[bool] = ..., revoked_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class RestoreServiceAccountRequest(_message.Message):
    __slots__ = ("id", "reason")
    ID_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    id: str
    reason: str
    def __init__(self, id: _Optional[str] = ..., reason: _Optional[str] = ...) -> None: ...

class RestoreServiceAccountResponse(_message.Message):
    __slots__ = ("success", "service_account")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    SERVICE_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    success: bool
    service_account: ServiceAccountInfo
    def __init__(self, success: _Optional[bool] = ..., service_account: _Optional[_Union[ServiceAccountInfo, _Mapping]] = ...) -> None: ...

class CreateUserTokenRequest(_message.Message):
    __slots__ = ("customer_id", "workspace_id", "user_id", "role", "organization_unit", "expires_in_days", "scopes", "name", "impersonate", "impersonation_metadata")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    WORKSPACE_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATION_UNIT_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_IN_DAYS_FIELD_NUMBER: _ClassVar[int]
    SCOPES_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    IMPERSONATE_FIELD_NUMBER: _ClassVar[int]
    IMPERSONATION_METADATA_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    workspace_id: str
    user_id: str
    role: str
    organization_unit: str
    expires_in_days: int
    scopes: _containers.RepeatedScalarFieldContainer[str]
    name: str
    impersonate: bool
    impersonation_metadata: ImpersonationMetadata
    def __init__(self, customer_id: _Optional[str] = ..., workspace_id: _Optional[str] = ..., user_id: _Optional[str] = ..., role: _Optional[str] = ..., organization_unit: _Optional[str] = ..., expires_in_days: _Optional[int] = ..., scopes: _Optional[_Iterable[str]] = ..., name: _Optional[str] = ..., impersonate: _Optional[bool] = ..., impersonation_metadata: _Optional[_Union[ImpersonationMetadata, _Mapping]] = ...) -> None: ...

class ImpersonationMetadata(_message.Message):
    __slots__ = ("impersonator_key", "reason", "context")
    class ContextEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    IMPERSONATOR_KEY_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_FIELD_NUMBER: _ClassVar[int]
    impersonator_key: str
    reason: str
    context: _containers.ScalarMap[str, str]
    def __init__(self, impersonator_key: _Optional[str] = ..., reason: _Optional[str] = ..., context: _Optional[_Mapping[str, str]] = ...) -> None: ...

class CreateUserTokenResponse(_message.Message):
    __slots__ = ("access_token", "token_type", "expires_in", "expires_at", "jti", "key_prefix", "key_hash", "key_address")
    ACCESS_TOKEN_FIELD_NUMBER: _ClassVar[int]
    TOKEN_TYPE_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_IN_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    JTI_FIELD_NUMBER: _ClassVar[int]
    KEY_PREFIX_FIELD_NUMBER: _ClassVar[int]
    KEY_HASH_FIELD_NUMBER: _ClassVar[int]
    KEY_ADDRESS_FIELD_NUMBER: _ClassVar[int]
    access_token: str
    token_type: str
    expires_in: int
    expires_at: _timestamp_pb2.Timestamp
    jti: str
    key_prefix: str
    key_hash: str
    key_address: str
    def __init__(self, access_token: _Optional[str] = ..., token_type: _Optional[str] = ..., expires_in: _Optional[int] = ..., expires_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., jti: _Optional[str] = ..., key_prefix: _Optional[str] = ..., key_hash: _Optional[str] = ..., key_address: _Optional[str] = ...) -> None: ...

class ListUserTokensRequest(_message.Message):
    __slots__ = ("user_id", "status", "page_size", "page_token")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    status: UserTokenStatus
    page_size: int
    page_token: str
    def __init__(self, user_id: _Optional[str] = ..., status: _Optional[_Union[UserTokenStatus, str]] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class ListUserTokensResponse(_message.Message):
    __slots__ = ("tokens", "next_page_token")
    TOKENS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    tokens: _containers.RepeatedCompositeFieldContainer[UserTokenInfo]
    next_page_token: str
    def __init__(self, tokens: _Optional[_Iterable[_Union[UserTokenInfo, _Mapping]]] = ..., next_page_token: _Optional[str] = ...) -> None: ...

class GetUserTokenRequest(_message.Message):
    __slots__ = ("jti",)
    JTI_FIELD_NUMBER: _ClassVar[int]
    jti: str
    def __init__(self, jti: _Optional[str] = ...) -> None: ...

class GetUserTokenResponse(_message.Message):
    __slots__ = ("token",)
    TOKEN_FIELD_NUMBER: _ClassVar[int]
    token: UserTokenInfo
    def __init__(self, token: _Optional[_Union[UserTokenInfo, _Mapping]] = ...) -> None: ...

class UserTokenInfo(_message.Message):
    __slots__ = ("jti", "user_id", "role", "organization_unit", "status", "created_at", "expires_at", "last_used_at", "revoked_at", "revoked_reason")
    JTI_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    ORGANIZATION_UNIT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    EXPIRES_AT_FIELD_NUMBER: _ClassVar[int]
    LAST_USED_AT_FIELD_NUMBER: _ClassVar[int]
    REVOKED_AT_FIELD_NUMBER: _ClassVar[int]
    REVOKED_REASON_FIELD_NUMBER: _ClassVar[int]
    jti: str
    user_id: str
    role: str
    organization_unit: str
    status: UserTokenStatus
    created_at: _timestamp_pb2.Timestamp
    expires_at: _timestamp_pb2.Timestamp
    last_used_at: _timestamp_pb2.Timestamp
    revoked_at: _timestamp_pb2.Timestamp
    revoked_reason: str
    def __init__(self, jti: _Optional[str] = ..., user_id: _Optional[str] = ..., role: _Optional[str] = ..., organization_unit: _Optional[str] = ..., status: _Optional[_Union[UserTokenStatus, str]] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., expires_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., last_used_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., revoked_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., revoked_reason: _Optional[str] = ...) -> None: ...

class RevokeUserTokenRequest(_message.Message):
    __slots__ = ("jti", "reason")
    JTI_FIELD_NUMBER: _ClassVar[int]
    REASON_FIELD_NUMBER: _ClassVar[int]
    jti: str
    reason: str
    def __init__(self, jti: _Optional[str] = ..., reason: _Optional[str] = ...) -> None: ...

class RevokeUserTokenResponse(_message.Message):
    __slots__ = ("success", "revoked_at")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    REVOKED_AT_FIELD_NUMBER: _ClassVar[int]
    success: bool
    revoked_at: _timestamp_pb2.Timestamp
    def __init__(self, success: _Optional[bool] = ..., revoked_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class TelemetryForwardingConfig(_message.Message):
    __slots__ = ("id", "user_id", "telemetry_type", "sink_url", "protocol", "auth_type", "auth_value", "api_key_header", "enabled", "last_checked_at", "status", "created_at", "updated_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    TELEMETRY_TYPE_FIELD_NUMBER: _ClassVar[int]
    SINK_URL_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_FIELD_NUMBER: _ClassVar[int]
    AUTH_TYPE_FIELD_NUMBER: _ClassVar[int]
    AUTH_VALUE_FIELD_NUMBER: _ClassVar[int]
    API_KEY_HEADER_FIELD_NUMBER: _ClassVar[int]
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    LAST_CHECKED_AT_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    user_id: str
    telemetry_type: str
    sink_url: str
    protocol: str
    auth_type: str
    auth_value: str
    api_key_header: str
    enabled: bool
    last_checked_at: _timestamp_pb2.Timestamp
    status: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., user_id: _Optional[str] = ..., telemetry_type: _Optional[str] = ..., sink_url: _Optional[str] = ..., protocol: _Optional[str] = ..., auth_type: _Optional[str] = ..., auth_value: _Optional[str] = ..., api_key_header: _Optional[str] = ..., enabled: _Optional[bool] = ..., last_checked_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., status: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class CreateTelemetryConfigRequest(_message.Message):
    __slots__ = ("user_id", "telemetry_type", "sink_url", "protocol", "auth_type", "auth_value", "api_key_header", "enabled")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    TELEMETRY_TYPE_FIELD_NUMBER: _ClassVar[int]
    SINK_URL_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_FIELD_NUMBER: _ClassVar[int]
    AUTH_TYPE_FIELD_NUMBER: _ClassVar[int]
    AUTH_VALUE_FIELD_NUMBER: _ClassVar[int]
    API_KEY_HEADER_FIELD_NUMBER: _ClassVar[int]
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    telemetry_type: str
    sink_url: str
    protocol: str
    auth_type: str
    auth_value: str
    api_key_header: str
    enabled: bool
    def __init__(self, user_id: _Optional[str] = ..., telemetry_type: _Optional[str] = ..., sink_url: _Optional[str] = ..., protocol: _Optional[str] = ..., auth_type: _Optional[str] = ..., auth_value: _Optional[str] = ..., api_key_header: _Optional[str] = ..., enabled: _Optional[bool] = ...) -> None: ...

class CreateTelemetryConfigResponse(_message.Message):
    __slots__ = ("config",)
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    config: TelemetryForwardingConfig
    def __init__(self, config: _Optional[_Union[TelemetryForwardingConfig, _Mapping]] = ...) -> None: ...

class ListTelemetryConfigsRequest(_message.Message):
    __slots__ = ("user_id", "telemetry_type", "enabled")
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    TELEMETRY_TYPE_FIELD_NUMBER: _ClassVar[int]
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    user_id: str
    telemetry_type: str
    enabled: bool
    def __init__(self, user_id: _Optional[str] = ..., telemetry_type: _Optional[str] = ..., enabled: _Optional[bool] = ...) -> None: ...

class ListTelemetryConfigsResponse(_message.Message):
    __slots__ = ("configs", "total")
    CONFIGS_FIELD_NUMBER: _ClassVar[int]
    TOTAL_FIELD_NUMBER: _ClassVar[int]
    configs: _containers.RepeatedCompositeFieldContainer[TelemetryForwardingConfig]
    total: int
    def __init__(self, configs: _Optional[_Iterable[_Union[TelemetryForwardingConfig, _Mapping]]] = ..., total: _Optional[int] = ...) -> None: ...

class GetTelemetryConfigRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class GetTelemetryConfigResponse(_message.Message):
    __slots__ = ("config",)
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    config: TelemetryForwardingConfig
    def __init__(self, config: _Optional[_Union[TelemetryForwardingConfig, _Mapping]] = ...) -> None: ...

class UpdateTelemetryConfigRequest(_message.Message):
    __slots__ = ("id", "sink_url", "protocol", "auth_type", "auth_value", "api_key_header", "enabled", "status")
    ID_FIELD_NUMBER: _ClassVar[int]
    SINK_URL_FIELD_NUMBER: _ClassVar[int]
    PROTOCOL_FIELD_NUMBER: _ClassVar[int]
    AUTH_TYPE_FIELD_NUMBER: _ClassVar[int]
    AUTH_VALUE_FIELD_NUMBER: _ClassVar[int]
    API_KEY_HEADER_FIELD_NUMBER: _ClassVar[int]
    ENABLED_FIELD_NUMBER: _ClassVar[int]
    STATUS_FIELD_NUMBER: _ClassVar[int]
    id: str
    sink_url: str
    protocol: str
    auth_type: str
    auth_value: str
    api_key_header: str
    enabled: bool
    status: str
    def __init__(self, id: _Optional[str] = ..., sink_url: _Optional[str] = ..., protocol: _Optional[str] = ..., auth_type: _Optional[str] = ..., auth_value: _Optional[str] = ..., api_key_header: _Optional[str] = ..., enabled: _Optional[bool] = ..., status: _Optional[str] = ...) -> None: ...

class UpdateTelemetryConfigResponse(_message.Message):
    __slots__ = ("config",)
    CONFIG_FIELD_NUMBER: _ClassVar[int]
    config: TelemetryForwardingConfig
    def __init__(self, config: _Optional[_Union[TelemetryForwardingConfig, _Mapping]] = ...) -> None: ...

class DeleteTelemetryConfigRequest(_message.Message):
    __slots__ = ("id",)
    ID_FIELD_NUMBER: _ClassVar[int]
    id: str
    def __init__(self, id: _Optional[str] = ...) -> None: ...

class DeleteTelemetryConfigResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: _Optional[bool] = ...) -> None: ...

class Customer(_message.Message):
    __slots__ = ("id", "customer_id", "name", "description", "labels", "created_at", "updated_at", "deleted_at")
    class LabelsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    DELETED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    customer_id: str
    name: str
    description: str
    labels: _containers.ScalarMap[str, str]
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    deleted_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., customer_id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., labels: _Optional[_Mapping[str, str]] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., deleted_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class CreateCustomerRequest(_message.Message):
    __slots__ = ("customer_id", "name", "description", "labels")
    class LabelsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    name: str
    description: str
    labels: _containers.ScalarMap[str, str]
    def __init__(self, customer_id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., labels: _Optional[_Mapping[str, str]] = ...) -> None: ...

class CreateCustomerResponse(_message.Message):
    __slots__ = ("customer",)
    CUSTOMER_FIELD_NUMBER: _ClassVar[int]
    customer: Customer
    def __init__(self, customer: _Optional[_Union[Customer, _Mapping]] = ...) -> None: ...

class ListCustomersRequest(_message.Message):
    __slots__ = ("page_size", "page_token")
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    page_size: int
    page_token: str
    def __init__(self, page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class ListCustomersResponse(_message.Message):
    __slots__ = ("customers", "next_page_token")
    CUSTOMERS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    customers: _containers.RepeatedCompositeFieldContainer[Customer]
    next_page_token: str
    def __init__(self, customers: _Optional[_Iterable[_Union[Customer, _Mapping]]] = ..., next_page_token: _Optional[str] = ...) -> None: ...

class GetCustomerRequest(_message.Message):
    __slots__ = ("customer_id",)
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    def __init__(self, customer_id: _Optional[str] = ...) -> None: ...

class GetCustomerResponse(_message.Message):
    __slots__ = ("customer",)
    CUSTOMER_FIELD_NUMBER: _ClassVar[int]
    customer: Customer
    def __init__(self, customer: _Optional[_Union[Customer, _Mapping]] = ...) -> None: ...

class UpdateCustomerRequest(_message.Message):
    __slots__ = ("customer_id", "name", "description", "labels")
    class LabelsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    name: str
    description: str
    labels: _containers.ScalarMap[str, str]
    def __init__(self, customer_id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., labels: _Optional[_Mapping[str, str]] = ...) -> None: ...

class UpdateCustomerResponse(_message.Message):
    __slots__ = ("customer",)
    CUSTOMER_FIELD_NUMBER: _ClassVar[int]
    customer: Customer
    def __init__(self, customer: _Optional[_Union[Customer, _Mapping]] = ...) -> None: ...

class DeleteCustomerRequest(_message.Message):
    __slots__ = ("customer_id",)
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    def __init__(self, customer_id: _Optional[str] = ...) -> None: ...

class DeleteCustomerResponse(_message.Message):
    __slots__ = ("success", "deleted_at")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    DELETED_AT_FIELD_NUMBER: _ClassVar[int]
    success: bool
    deleted_at: _timestamp_pb2.Timestamp
    def __init__(self, success: _Optional[bool] = ..., deleted_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class Project(_message.Message):
    __slots__ = ("id", "customer_id", "project_id", "name", "description", "labels", "created_at", "updated_at", "deleted_at")
    class LabelsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    ID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    DELETED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    customer_id: str
    project_id: str
    name: str
    description: str
    labels: _containers.ScalarMap[str, str]
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    deleted_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., labels: _Optional[_Mapping[str, str]] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., deleted_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class CreateProjectRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "name", "description", "labels")
    class LabelsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    name: str
    description: str
    labels: _containers.ScalarMap[str, str]
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., labels: _Optional[_Mapping[str, str]] = ...) -> None: ...

class CreateProjectResponse(_message.Message):
    __slots__ = ("project",)
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    project: Project
    def __init__(self, project: _Optional[_Union[Project, _Mapping]] = ...) -> None: ...

class ListProjectsRequest(_message.Message):
    __slots__ = ("customer_id", "page_size", "page_token")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PAGE_SIZE_FIELD_NUMBER: _ClassVar[int]
    PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    page_size: int
    page_token: str
    def __init__(self, customer_id: _Optional[str] = ..., page_size: _Optional[int] = ..., page_token: _Optional[str] = ...) -> None: ...

class ListProjectsResponse(_message.Message):
    __slots__ = ("projects", "next_page_token")
    PROJECTS_FIELD_NUMBER: _ClassVar[int]
    NEXT_PAGE_TOKEN_FIELD_NUMBER: _ClassVar[int]
    projects: _containers.RepeatedCompositeFieldContainer[Project]
    next_page_token: str
    def __init__(self, projects: _Optional[_Iterable[_Union[Project, _Mapping]]] = ..., next_page_token: _Optional[str] = ...) -> None: ...

class GetProjectRequest(_message.Message):
    __slots__ = ("customer_id", "project_id")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ...) -> None: ...

class GetProjectResponse(_message.Message):
    __slots__ = ("project",)
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    project: Project
    def __init__(self, project: _Optional[_Union[Project, _Mapping]] = ...) -> None: ...

class UpdateProjectRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "name", "description", "labels")
    class LabelsEntry(_message.Message):
        __slots__ = ("key", "value")
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    NAME_FIELD_NUMBER: _ClassVar[int]
    DESCRIPTION_FIELD_NUMBER: _ClassVar[int]
    LABELS_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    name: str
    description: str
    labels: _containers.ScalarMap[str, str]
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., name: _Optional[str] = ..., description: _Optional[str] = ..., labels: _Optional[_Mapping[str, str]] = ...) -> None: ...

class UpdateProjectResponse(_message.Message):
    __slots__ = ("project",)
    PROJECT_FIELD_NUMBER: _ClassVar[int]
    project: Project
    def __init__(self, project: _Optional[_Union[Project, _Mapping]] = ...) -> None: ...

class DeleteProjectRequest(_message.Message):
    __slots__ = ("customer_id", "project_id")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ...) -> None: ...

class DeleteProjectResponse(_message.Message):
    __slots__ = ("success", "deleted_at")
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    DELETED_AT_FIELD_NUMBER: _ClassVar[int]
    success: bool
    deleted_at: _timestamp_pb2.Timestamp
    def __init__(self, success: _Optional[bool] = ..., deleted_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class ProjectMember(_message.Message):
    __slots__ = ("id", "customer_id", "project_id", "user_id", "role", "created_at", "updated_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    customer_id: str
    project_id: str
    user_id: str
    role: str
    created_at: _timestamp_pb2.Timestamp
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., user_id: _Optional[str] = ..., role: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class AddProjectMemberRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "user_id", "role")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    user_id: str
    role: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., user_id: _Optional[str] = ..., role: _Optional[str] = ...) -> None: ...

class AddProjectMemberResponse(_message.Message):
    __slots__ = ("member",)
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    member: ProjectMember
    def __init__(self, member: _Optional[_Union[ProjectMember, _Mapping]] = ...) -> None: ...

class ListProjectMembersRequest(_message.Message):
    __slots__ = ("customer_id", "project_id")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ...) -> None: ...

class ListProjectMembersResponse(_message.Message):
    __slots__ = ("members",)
    MEMBERS_FIELD_NUMBER: _ClassVar[int]
    members: _containers.RepeatedCompositeFieldContainer[ProjectMember]
    def __init__(self, members: _Optional[_Iterable[_Union[ProjectMember, _Mapping]]] = ...) -> None: ...

class UpdateProjectMemberRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "user_id", "role")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    ROLE_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    user_id: str
    role: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., user_id: _Optional[str] = ..., role: _Optional[str] = ...) -> None: ...

class UpdateProjectMemberResponse(_message.Message):
    __slots__ = ("member",)
    MEMBER_FIELD_NUMBER: _ClassVar[int]
    member: ProjectMember
    def __init__(self, member: _Optional[_Union[ProjectMember, _Mapping]] = ...) -> None: ...

class RemoveProjectMemberRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "user_id")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    USER_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    user_id: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., user_id: _Optional[str] = ...) -> None: ...

class RemoveProjectMemberResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: _Optional[bool] = ...) -> None: ...

class AIModel(_message.Message):
    __slots__ = ("id", "model", "provider", "mode", "is_enabled", "input_price_per_million", "output_price_per_million", "context_window", "capabilities")
    ID_FIELD_NUMBER: _ClassVar[int]
    MODEL_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_FIELD_NUMBER: _ClassVar[int]
    MODE_FIELD_NUMBER: _ClassVar[int]
    IS_ENABLED_FIELD_NUMBER: _ClassVar[int]
    INPUT_PRICE_PER_MILLION_FIELD_NUMBER: _ClassVar[int]
    OUTPUT_PRICE_PER_MILLION_FIELD_NUMBER: _ClassVar[int]
    CONTEXT_WINDOW_FIELD_NUMBER: _ClassVar[int]
    CAPABILITIES_FIELD_NUMBER: _ClassVar[int]
    id: str
    model: str
    provider: str
    mode: str
    is_enabled: bool
    input_price_per_million: float
    output_price_per_million: float
    context_window: int
    capabilities: _containers.RepeatedScalarFieldContainer[str]
    def __init__(self, id: _Optional[str] = ..., model: _Optional[str] = ..., provider: _Optional[str] = ..., mode: _Optional[str] = ..., is_enabled: _Optional[bool] = ..., input_price_per_million: _Optional[float] = ..., output_price_per_million: _Optional[float] = ..., context_window: _Optional[int] = ..., capabilities: _Optional[_Iterable[str]] = ...) -> None: ...

class ListModelsRequest(_message.Message):
    __slots__ = ("only_enabled",)
    ONLY_ENABLED_FIELD_NUMBER: _ClassVar[int]
    only_enabled: bool
    def __init__(self, only_enabled: _Optional[bool] = ...) -> None: ...

class ListModelsResponse(_message.Message):
    __slots__ = ("models",)
    MODELS_FIELD_NUMBER: _ClassVar[int]
    models: _containers.RepeatedCompositeFieldContainer[AIModel]
    def __init__(self, models: _Optional[_Iterable[_Union[AIModel, _Mapping]]] = ...) -> None: ...

class GetModelRequest(_message.Message):
    __slots__ = ("model_id",)
    MODEL_ID_FIELD_NUMBER: _ClassVar[int]
    model_id: str
    def __init__(self, model_id: _Optional[str] = ...) -> None: ...

class GetModelResponse(_message.Message):
    __slots__ = ("model",)
    MODEL_FIELD_NUMBER: _ClassVar[int]
    model: AIModel
    def __init__(self, model: _Optional[_Union[AIModel, _Mapping]] = ...) -> None: ...

class ProjectModelEntry(_message.Message):
    __slots__ = ("id", "customer_id", "project_id", "model_id", "model", "created_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    MODEL_ID_FIELD_NUMBER: _ClassVar[int]
    MODEL_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    customer_id: str
    project_id: str
    model_id: str
    model: AIModel
    created_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., model_id: _Optional[str] = ..., model: _Optional[_Union[AIModel, _Mapping]] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class AddProjectModelRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "model_id")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    MODEL_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    model_id: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., model_id: _Optional[str] = ...) -> None: ...

class AddProjectModelResponse(_message.Message):
    __slots__ = ("entry",)
    ENTRY_FIELD_NUMBER: _ClassVar[int]
    entry: ProjectModelEntry
    def __init__(self, entry: _Optional[_Union[ProjectModelEntry, _Mapping]] = ...) -> None: ...

class ListProjectModelsRequest(_message.Message):
    __slots__ = ("customer_id", "project_id")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ...) -> None: ...

class ListProjectModelsResponse(_message.Message):
    __slots__ = ("entries",)
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    entries: _containers.RepeatedCompositeFieldContainer[ProjectModelEntry]
    def __init__(self, entries: _Optional[_Iterable[_Union[ProjectModelEntry, _Mapping]]] = ...) -> None: ...

class RemoveProjectModelRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "model_id")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    MODEL_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    model_id: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., model_id: _Optional[str] = ...) -> None: ...

class RemoveProjectModelResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: _Optional[bool] = ...) -> None: ...

class ProjectProviderEntry(_message.Message):
    __slots__ = ("id", "customer_id", "project_id", "provider_name", "created_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_NAME_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    customer_id: str
    project_id: str
    provider_name: str
    created_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., provider_name: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class AddProjectProviderRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "provider_name")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_NAME_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    provider_name: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., provider_name: _Optional[str] = ...) -> None: ...

class AddProjectProviderResponse(_message.Message):
    __slots__ = ("entry",)
    ENTRY_FIELD_NUMBER: _ClassVar[int]
    entry: ProjectProviderEntry
    def __init__(self, entry: _Optional[_Union[ProjectProviderEntry, _Mapping]] = ...) -> None: ...

class ListProjectProvidersRequest(_message.Message):
    __slots__ = ("customer_id", "project_id")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ...) -> None: ...

class ListProjectProvidersResponse(_message.Message):
    __slots__ = ("entries",)
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    entries: _containers.RepeatedCompositeFieldContainer[ProjectProviderEntry]
    def __init__(self, entries: _Optional[_Iterable[_Union[ProjectProviderEntry, _Mapping]]] = ...) -> None: ...

class RemoveProjectProviderRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "provider_name")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    PROVIDER_NAME_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    provider_name: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., provider_name: _Optional[str] = ...) -> None: ...

class RemoveProjectProviderResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: _Optional[bool] = ...) -> None: ...

class ProjectMcpServerEntry(_message.Message):
    __slots__ = ("id", "customer_id", "project_id", "server_id", "created_at")
    ID_FIELD_NUMBER: _ClassVar[int]
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    SERVER_ID_FIELD_NUMBER: _ClassVar[int]
    CREATED_AT_FIELD_NUMBER: _ClassVar[int]
    id: str
    customer_id: str
    project_id: str
    server_id: str
    created_at: _timestamp_pb2.Timestamp
    def __init__(self, id: _Optional[str] = ..., customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., server_id: _Optional[str] = ..., created_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class AddProjectMcpServerRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "server_id")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    SERVER_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    server_id: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., server_id: _Optional[str] = ...) -> None: ...

class AddProjectMcpServerResponse(_message.Message):
    __slots__ = ("entry",)
    ENTRY_FIELD_NUMBER: _ClassVar[int]
    entry: ProjectMcpServerEntry
    def __init__(self, entry: _Optional[_Union[ProjectMcpServerEntry, _Mapping]] = ...) -> None: ...

class ListProjectMcpServersRequest(_message.Message):
    __slots__ = ("customer_id", "project_id")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ...) -> None: ...

class ListProjectMcpServersResponse(_message.Message):
    __slots__ = ("entries",)
    ENTRIES_FIELD_NUMBER: _ClassVar[int]
    entries: _containers.RepeatedCompositeFieldContainer[ProjectMcpServerEntry]
    def __init__(self, entries: _Optional[_Iterable[_Union[ProjectMcpServerEntry, _Mapping]]] = ...) -> None: ...

class RemoveProjectMcpServerRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "server_id")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    SERVER_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    server_id: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., server_id: _Optional[str] = ...) -> None: ...

class RemoveProjectMcpServerResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: _Optional[bool] = ...) -> None: ...

class ProjectSetting(_message.Message):
    __slots__ = ("setting_name", "setting_value", "updated_at")
    SETTING_NAME_FIELD_NUMBER: _ClassVar[int]
    SETTING_VALUE_FIELD_NUMBER: _ClassVar[int]
    UPDATED_AT_FIELD_NUMBER: _ClassVar[int]
    setting_name: str
    setting_value: str
    updated_at: _timestamp_pb2.Timestamp
    def __init__(self, setting_name: _Optional[str] = ..., setting_value: _Optional[str] = ..., updated_at: _Optional[_Union[datetime.datetime, _timestamp_pb2.Timestamp, _Mapping]] = ...) -> None: ...

class GetProjectSettingsRequest(_message.Message):
    __slots__ = ("customer_id", "project_id")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ...) -> None: ...

class GetProjectSettingsResponse(_message.Message):
    __slots__ = ("settings",)
    SETTINGS_FIELD_NUMBER: _ClassVar[int]
    settings: _containers.RepeatedCompositeFieldContainer[ProjectSetting]
    def __init__(self, settings: _Optional[_Iterable[_Union[ProjectSetting, _Mapping]]] = ...) -> None: ...

class UpsertProjectSettingRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "setting_name", "setting_value")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    SETTING_NAME_FIELD_NUMBER: _ClassVar[int]
    SETTING_VALUE_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    setting_name: str
    setting_value: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., setting_name: _Optional[str] = ..., setting_value: _Optional[str] = ...) -> None: ...

class UpsertProjectSettingResponse(_message.Message):
    __slots__ = ("setting",)
    SETTING_FIELD_NUMBER: _ClassVar[int]
    setting: ProjectSetting
    def __init__(self, setting: _Optional[_Union[ProjectSetting, _Mapping]] = ...) -> None: ...

class DeleteProjectSettingRequest(_message.Message):
    __slots__ = ("customer_id", "project_id", "setting_name")
    CUSTOMER_ID_FIELD_NUMBER: _ClassVar[int]
    PROJECT_ID_FIELD_NUMBER: _ClassVar[int]
    SETTING_NAME_FIELD_NUMBER: _ClassVar[int]
    customer_id: str
    project_id: str
    setting_name: str
    def __init__(self, customer_id: _Optional[str] = ..., project_id: _Optional[str] = ..., setting_name: _Optional[str] = ...) -> None: ...

class DeleteProjectSettingResponse(_message.Message):
    __slots__ = ("success",)
    SUCCESS_FIELD_NUMBER: _ClassVar[int]
    success: bool
    def __init__(self, success: _Optional[bool] = ...) -> None: ...
